==> vtk-6.3.0-5-aarch64.pkg.tar.xz: vtk/vtkInteractorStyleTerrain.java <==
// java wrapper for vtkInteractorStyleTerrain object
//

package vtk;
import vtk.*;

public class vtkInteractorStyleTerrain extends vtkInteractorStyle
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void OnMouseMove_2();
  public void OnMouseMove()
    { OnMouseMove_2(); }

  private native void OnLeftButtonDown_3();
  public void OnLeftButtonDown()
    { OnLeftButtonDown_3(); }

  private native void OnLeftButtonUp_4();
  public void OnLeftButtonUp()
    { OnLeftButtonUp_4(); }

  private native void OnMiddleButtonDown_5();
  public void OnMiddleButtonDown()
    { OnMiddleButtonDown_5(); }

  private native void OnMiddleButtonUp_6();
  public void OnMiddleButtonUp()
    { OnMiddleButtonUp_6(); }

  private native void OnRightButtonDown_7();
  public void OnRightButtonDown()
    { OnRightButtonDown_7(); }

  private native void OnRightButtonUp_8();
  public void OnRightButtonUp()
    { OnRightButtonUp_8(); }

  private native void OnChar_9();
  public void OnChar()
    { OnChar_9(); }

  private native void Rotate_10();
  public void Rotate()
    { Rotate_10(); }

  private native void Pan_11();
  public void Pan()
    { Pan_11(); }

  private native void Dolly_12();
  public void Dolly()
    { Dolly_12(); }

  private native void SetLatLongLines_13(int id0);
  public void SetLatLongLines(int id0)
    { SetLatLongLines_13(id0); }

  private native int GetLatLongLines_14();
  public int GetLatLongLines()
    { return GetLatLongLines_14(); }

  private native void LatLongLinesOn_15();
  public void LatLongLinesOn()
    { LatLongLinesOn_15(); }

  private native void LatLongLinesOff_16();
  public void LatLongLinesOff()
    { LatLongLinesOff_16(); }

  public vtkInteractorStyleTerrain() { super(); }

  public vtkInteractorStyleTerrain(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-9-aarch64.pkg.tar.xz: vtk/vtkInteractorStyleTerrain.java <==
// java wrapper for vtkInteractorStyleTerrain object
//

package vtk;
import vtk.*;

public class vtkInteractorStyleTerrain extends vtkInteractorStyle
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void OnMouseMove_2();
  public void OnMouseMove()
    { OnMouseMove_2(); }

  private native void OnLeftButtonDown_3();
  public void OnLeftButtonDown()
    { OnLeftButtonDown_3(); }

  private native void OnLeftButtonUp_4();
  public void OnLeftButtonUp()
    { OnLeftButtonUp_4(); }

  private native void OnMiddleButtonDown_5();
  public void OnMiddleButtonDown()
    { OnMiddleButtonDown_5(); }

  private native void OnMiddleButtonUp_6();
  public void OnMiddleButtonUp()
    { OnMiddleButtonUp_6(); }

  private native void OnRightButtonDown_7();
  public void OnRightButtonDown()
    { OnRightButtonDown_7(); }

  private native void OnRightButtonUp_8();
  public void OnRightButtonUp()
    { OnRightButtonUp_8(); }

  private native void OnChar_9();
  public void OnChar()
    { OnChar_9(); }

  private native void Rotate_10();
  public void Rotate()
    { Rotate_10(); }

  private native void Pan_11();
  public void Pan()
    { Pan_11(); }

  private native void Dolly_12();
  public void Dolly()
    { Dolly_12(); }

  private native void SetLatLongLines_13(int id0);
  public void SetLatLongLines(int id0)
    { SetLatLongLines_13(id0); }

  private native int GetLatLongLines_14();
  public int GetLatLongLines()
    { return GetLatLongLines_14(); }

  private native void LatLongLinesOn_15();
  public void LatLongLinesOn()
    { LatLongLinesOn_15(); }

  private native void LatLongLinesOff_16();
  public void LatLongLinesOff()
    { LatLongLinesOff_16(); }

  public vtkInteractorStyleTerrain() { super(); }

  public vtkInteractorStyleTerrain(long id) { super(id); }
  public native long   VTKInit();

}
